# Developer documentation

This page gives an overview of how to get started with developing DiracX itself and will walk you through setting up a local development environment for the main DiracX components.
This page will not help you if:

- You're a user of a DiracX installation looking for how to submit jobs, access data or similar. See the [User Guide](../user/index.md).
- You're instead looking to develop software which uses DiracX programmatically, e.g. to submit jobs.
    Instead check out the user documentation on [programmatic access](../user/reference/programmatic-usage/index.md).
- You're an installation admin looking to install, manage or debug your DiracX installation. See the [Administrator Guide](../admin/index.md).
- You're only interested in developing `diracx-web`, see the [dedicated tutorial](...).
- You already know how to develop DiracX and are looking for specific information, see the sidebar on the left for more specific or in-depth documentation.
